@@ -157,7 +157,7 @@ register(hc.less_than_or_equal_to,
 register(hc.has_length,
          'have_length', 'have_len')
 register(hc.has_property,
-         'have_the_property', 'contain_the_property')
+         'have_the_property', 'contain_the_property', 'have_the_prop', 'contain_the_prop')
 register(hc.has_string,
          'have_the_string', 'contain_the_string')
 register(hc.equal_to_ignoring_case,
@@ -387,11 +387,22 @@ register(IsFalsy, 'be_a_falsy_value', 'be_falsy')
 class IsEmpty(BaseMatcher):
     """ Check if a value is empty """
     def _matches(self, item):
-        return True if not len(item) else False
+        try:
+            return bool(len(item))
+        except:
+            return False
 
     def describe_to(self, desc):
         desc.append_text('an empty value')
 
+    def describe_mismatch(self, item, desc):
+        try:
+            l = len(item)
+            desc.append_text('has {0} elements'.format(l))
+        except:
+            desc.append_value(item)
+            desc.append_text(' does not have a length')
+
 register(IsEmpty, 'be_empty')
 
 
@@ -541,7 +552,13 @@ class Callback(BaseMatcher):
     def _matches(self, item):
         self.error = None
         try:
-            return bool(self.callback(item))
+            result = self.callback(item)
+            # Returning an expectation assumes it's correct (no failure raised)
+            from .expectation import Expectation
+            return isinstance(result, Expectation) or bool(result)
+        except AssertionError:
+            # Just forward assertion failures
+            raise
         except Exception as ex:
             self.error = str(ex)
             return False
@@ -562,3 +579,23 @@ class Callback(BaseMatcher):
 
 register(Callback,
          'callback', 'pass', 'pass_callback')
+
+
+class MockCalled(BaseMatcher):
+    """ Support for checking if mocks where called from the Mock library
+    """
+    def _matches(self, item):
+        if not hasattr(item, 'called'):
+            raise Exception('Mock object does not have a <called> attribute')
+        return item.called
+
+    def describe_to(self, desc):
+        desc.append_text('called')
+
+    def describe_mismatch(self, item, desc):
+        if item.called:
+            desc.append_text('was called')
+        else:
+            desc.append_text('was not called')
+
+register(MockCalled, 'called', 'invoked')
